@@ -1,12 +1,16 @@
 import itertools, time, requests
 
-import  settings
-import  files
+#  Note: need to import from package when running from wheel.
+# if running locally through main.py file, these imports should be replaced
+#       from . import settings, from . import files
+# annoying, but it is what it is.
+from scrilla import settings
+from scrilla import files 
 
-import  util.outputter as outputter
-import  util.helper as helper
+import util.outputter as outputter
+import util.helper as helper
 
-logger = outputter.Logger(" services", settings.LOG_LEVEL)
+logger = outputter.Logger("services", settings.LOG_LEVEL)
 
 CLOSE_PRICE = "close"
 OPEN_PRICE = "open"
